@@ -1,6 +1,8 @@
 #!usr/bin/env python
 import sys
 import os
+sys.path.insert(0, os.path.dirname(os.path.abspath(__file__)))
+print(sys.path)
 import argparse
 import logging
 import configparser
